<?php
/**
 *	FreshTheme Framework Admin Interface
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki A.G
 *	@version	: 1.2
 *	@copyright	: Copyright (c) 2012, FreshThemes
 *				  http://www.20script.ir
 *				  http://www.rifki.net
 *	@credits	: Devin Price, http://wptheming.com/
 *	              WooThemes, http://www.woothemes.com/
 *				  Gilles Vauvarin
 *	--------------------------------------------------------------------------- */

/*	Create menu tabs.
 *	------------------------------------------------------------------- */
	function freshthemes_menu_tabs() {
		$freshthemes_settings = get_option('freshthemes');
		$options = freshthemes_options();
		$menu = '';
		$prev_heading_key = 0;
		$menu_items = array();
		$headings = array();
		
		foreach ( $options as $k => $v ) {
			if ( $v['type'] == 'heading' || $v['type'] == 'subheading' ) {
				$headings[] = $v;
			}
		}
		
		foreach ( $headings as $k => $v ) {
			$token = 'freshthemes-option-' . preg_replace( '/[^a-zA-Z0-9\s]/', '', strtolower( trim( str_replace( ' ', '', $v['std'] ) ) ) );
			$v['token'] = $token;
			
			if ( $v['type'] == 'heading' ) {
				$menu_items[$token] = $v;
				$prev_heading_key = $token;
			}
			
			if ( $v['type'] == 'subheading' ) {
				$menu_items[$prev_heading_key]['children'][] = $v;
			}
		}
		
		if ( count($menu_items) > 0 ) {
			
			foreach ($menu_items as $k => $v) {
				$class = '';
				$click_hook = '';
				
				if ( isset( $v['icon'] ) && ( $v['icon'] != '' ) ) {
					$class = $v['icon'];
				}
				
				if ( isset( $v['token'] ) && ( $v['token'] != '' ) ) {
					$click_hook = $v['token'] . '-trigger';
				}
				
				if ( isset( $v['children'] ) && ( count( $v['children'] ) > 0 ) ) {
					$class .= ' has-children';
				}
				
				$menu .= '<li id="' . $click_hook . '" class="top-level ' . $class . '">' . "\n" . '<div class="arrow"><div></div></div>'; 
				
				if ( isset( $v['icon'] ) && ( $v['icon'] != '' ) ) 
				$menu .= '<span class="icon"></span>';
				
				$menu .= '<a title="' . esc_attr( $v['name'] ) . '" href="#' . $v['token'] . '">';
				$menu .= esc_html( $v['name'] );
				$menu .= '</a>' . "\n";
				
				if ( isset( $v['children'] ) && ( count( $v['children'] ) > 0 ) ) {
					$menu .= '<ul class="sub-menu">' . "\n";
						foreach ( $v['children'] as $i => $j ) {
							$click_hook = $j['token'] . '-trigger';
							$menu .= '<li id="' . $click_hook . '" class="icon">' . "\n" . '<a href="#' . $j['token'] . '">' . esc_html( $j['name'] ) . '</a></li>' . "\n";
						}
					$menu .= '</ul>' . "\n";
				}
				
				$menu .= '</li>' . "\n";
			}
			
			$menu .= '<li class="white-divider"></li>' . "\n";
		}
		
		return $menu;
	}
	
/* 	Create options field.
 * 	------------------------------------------------------------------- */
	function freshthemes_fields() {
		global $allowedtags;
		$freshthemes_settings = get_option('freshthemes');
	
		if ( isset( $freshthemes_settings['id'] ) ) {
			$option_name = $freshthemes_settings['id'];
		} else {
			$option_name = 'freshthemes';
		};
	
		$settings = get_option($option_name);
		$options = freshthemes_options();

		$counter = 0;
		
		foreach ( $options as $value ) {
			$counter++;
			$val = '';
			$select_value = '';
			$checked = '';
			$output = '';
			
			if ( ( $value['type'] != 'heading' ) && ( $value['type'] != 'subheading' ) && ( $value['type'] != 'info' ) ) {
				$value['id'] = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['id']) );
				$id = 'section-' . $value['id'];
				$class = 'section ';
			
				if ( isset( $value['type'] ) ) {
					$class .= 'section-' . $value['type'];
				}
				if ( isset( $value['class'] ) ) {
					$class .= ' ' . $value['class'];
				}

				$output .= '<div id="'. esc_attr($id) .'" class="'. esc_attr($class) .'">' . "\n";
			
				if ( isset( $value['name'] ) ) {
					$output .= '<h4 class="heading">'. esc_html( $value['name'] ) .'</h4>'."\n";
				}
				if ( $value['type'] != 'editor' ) {
					$output .= '<div class="option"><div class="controls">' . "\n";
				}
				else {
					$output .= '<div class="option"><div>' . "\n";
				}
			}
			
			/* Set default value to $val */
			if ( isset( $value['std'] ) ) {
				$val = $value['std'];
			}

			/* If the option is already saved, ovveride $val */
			if ( ( $value['type'] != 'heading' ) && ( $value['type'] != 'subheading') && ( $value['type'] != 'info') ) {
				if ( isset( $settings[($value['id'])]) ) {
					$val = $settings[($value['id'])];
					if ( !is_array($val) ) {
						$val = stripslashes( $val );
					}
				}
			}

			/* If there is a description save it for labels */
			$explain_value = '';
			if ( isset( $value['desc'] ) ) {
				$explain_value = $value['desc'];
			}

			switch ( $value['type'] ) {

				/* Text input */
				case 'text':
					$output .= '<input id="'. esc_attr( $value['id'] ) .'" class="freshthemes-input" name="'. esc_attr($option_name . '['. $value['id']. ']' ) .'" type="text" value="' . esc_attr( $val ) . '"' .( $value['placeholder'] != '' ? ' placeholder="'.$value['placeholder'].'"' : '' ) .' />';
					break;
					
				/* Textarea */
				case 'textarea':
					$rows = '8';

					if ( isset( $value['settings']['rows'] ) ) {
						$custom_rows = $value['settings']['rows'];
						if ( is_numeric( $custom_rows ) ) {
							$rows = $custom_rows;
						}
					}

					$val = stripslashes( $val );
					$output .= '<textarea id="'. esc_attr( $value['id'] ) .'" class="freshthemes-input" name="'. esc_attr( $option_name . '[' . $value['id'] . ']' ) .'" rows="' . $rows . '">'. esc_textarea( $val ) .'</textarea>';
					break;
			
				/* Select box */
				case 'select':
					$output .= '<select class="freshthemes-input" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" id="' . esc_attr( $value['id'] ) . '">';
					foreach ($value['options'] as $key => $option ) {
						$selected = '';
						if ( $val != '' ) {
							if ( $val == $key) { $selected = ' selected="selected"';}
						}
						$output .= '<option'. $selected .' value="' . esc_attr( $key ) . '">' . esc_html( $option ) . '</option>';
					}
					$output .= '</select>';
					break;
			
				/* Radio box */
				case 'radio':
					$name = $option_name .'['. $value['id'] .']';
					foreach ($value['options'] as $key => $option) {
						$id = $option_name . '-' . $value['id'] .'-'. $key;
						$output .= '<input class="freshthemes-input freshthemes-radio" type="radio" name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) . '" value="'. esc_attr( $key ) . '" '. checked( $val, $key, false) .' /><label for="' . esc_attr( $id ) . '">' . esc_html( $option ) . '</label>';
					}
					break;
		
				/* Image selector */
				case 'images':
					$name = $option_name .'['. $value['id'] .']';
					foreach ( $value['options'] as $key => $option ) {
						$selected = '';
						$checked = '';
						if ( $val != '' ) {
							if ( $val == $key ) {
								$selected = ' freshthemes-radio-img-selected';
								$checked = ' checked="checked"';
							}
						}
						$output .= '<input type="radio" id="' . esc_attr( $value['id'] .'_'. $key) . '" class="freshthemes-radio-img-radio" value="' . esc_attr( $key ) . '" name="' . esc_attr( $name ) . '" '. $checked .' />';
						$output .= '<div class="freshthemes-radio-img-label">' . esc_html( $key ) . '</div>';
						$output .= '<img src="' . esc_url( $option ) . '" alt="' . $option .'" class="freshthemes-radio-img-img' . $selected .'" onclick="document.getElementById(\''. esc_attr($value['id'] .'_'. $key) .'\').checked=true;" />';
					}
					break;
			
				/* Checkbox */
				case 'checkbox':
					$output .= '<input id="' . esc_attr( $value['id'] ) . '" class="checkbox freshthemes-input" type="checkbox" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" '. checked( $val, 1, false) .' />';
					$output .= '<label for="' . esc_attr( $value['id'] ) . '">' . wp_kses( $explain_value, $allowedtags) . '</label>';
					break;
					
				/* Multicheck */
				case 'multicheck':
					foreach ($value['options'] as $key => $option) {
						$checked = '';
						$label = $option;
						$option = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($key));
						$id = $option_name . '-' . $value['id'] . '-'. $option;
						$name = $option_name . '[' . $value['id'] . '][' . $option .']';

						if ( isset($val[$option]) ) {
							$checked = checked($val[$option], 1, false);
						}

						$output .= '<div class="checkbox-div"><input id="' . esc_attr( $id ) . '" class="checkbox freshthemes-input" type="checkbox" name="' . esc_attr( $name ) . '" ' . $checked . ' /><label for="' . esc_attr( $id ) . '">' . esc_html( $label ) . '</label></div>';
					}
					break;
			
				/* Color picker */
				case 'color':
					$output .= '<div class="colorSelector"><div style="' . esc_attr( 'background-color:' . $val ) . '"></div></div>';
					$output .= '<input class="freshthemes-color" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" id="' . esc_attr( $value['id'] ) . '" type="text" value="' . esc_attr( $val ) . '" />';
					break;
					
				/* Uploader */
				case "upload":
					$mode = '';
					$desc = '';
					
					if ( $value['class'] == 'mini' )
					$mode = 'mini';
					if ( isset($value['placeholder']) || $value['placeholder'] != '' )
					$desc = $value['placeholder'];
					
					$output .= freshthemes_medialibrary_uploader( $value['id'], $val, $mode, $desc, null );
					break;
					
				/* Typography */
				case 'typography':
		
					unset( $font_size, $font_style, $font_face, $font_color );
		
					$typography_defaults = array(
						'size' => '',
						'color' => ''
					);
			
					$typography_stored = wp_parse_args( $val, $typography_defaults );
			
					$typography_options = array(
						'sizes' => freshthemes_recognized_font_sizes(),
						'color' => true
					);
			
					if ( isset( $value['options'] ) ) {
						$typography_options = wp_parse_args( $value['options'], $typography_options );
					}

					// Font Size
					if ( $typography_options['sizes'] ) {
						$font_size = '<select class="freshthemes-typography freshthemes-typography-size" name="' . esc_attr( $option_name . '[' . $value['id'] . '][size]' ) . '" id="' . esc_attr( $value['id'] . '_size' ) . '">';
						$sizes = $typography_options['sizes'];
						foreach ( $sizes as $i ) {
							$size = $i . 'px';
							$font_size .= '<option value="' . esc_attr( $size ) . '" ' . selected( $typography_stored['size'], $size, false ) . '>' . esc_html( $size ) . '</option>';
						}
						$font_size .= '</select>';
					}


					// Font Color
					if ( $typography_options['color'] ) {
						$font_color = '<div id="' . esc_attr( $value['id'] ) . '_color_picker" class="colorSelector"><div style="' . esc_attr( 'background-color:' . $typography_stored['color'] ) . '"></div></div>';
						$font_color .= '<input class="freshthemes-color freshthemes-typography freshthemes-typography-color" name="' . esc_attr( $option_name . '[' . $value['id'] . '][color]' ) . '" id="' . esc_attr( $value['id'] . '_color' ) . '" type="text" value="' . esc_attr( $typography_stored['color'] ) . '" />';
					}
	
					// Allow modification/injection of typography fields
					$typography_fields = compact( 'font_size', 'font_color' );
					$typography_fields = apply_filters( 'freshthemes_typography_fields', $typography_fields, $typography_stored, $option_name, $value );
					$output .= implode( '', $typography_fields );
					break;
					
				/* Background */
				case 'background':

					$background = $val;

					// Background Color
					$output .= '<div id="' . esc_attr( $value['id'] ) . '_color_picker" class="colorSelector"><div style="' . esc_attr( 'background-color:' . $background['color'] ) . '"></div></div>';
					$output .= '<input class="freshthemes-color freshthemes-background freshthemes-background-color" name="' . esc_attr( $option_name . '[' . $value['id'] . '][color]' ) . '" id="' . esc_attr( $value['id'] . '_color' ) . '" type="text" value="' . esc_attr( $background['color'] ) . '" />';

					// Background Image - New AJAX Uploader using Media Library
					if (!isset($background['image'])) {
						$background['image'] = '';
					}	

					$output .= freshthemes_medialibrary_uploader( $value['id'], $background['image'], null, '',0,'image');
					$class = 'freshthemes-background-properties';
					if ( '' == $background['image'] ) {
						$class .= ' hide';
					}
					$output .= '<div class="' . esc_attr( $class ) . '">';

					// Background Repeat
					$output .= '<select class="freshthemes-background freshthemes-background-repeat" name="' . esc_attr( $option_name . '[' . $value['id'] . '][repeat]'  ) . '" id="' . esc_attr( $value['id'] . '_repeat' ) . '">';
					$repeats = freshthemes_recognized_background_repeat();

					foreach ($repeats as $key => $repeat) {
						$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $background['repeat'], $key, false ) . '>'. esc_html( $repeat ) . '</option>';
					}
					$output .= '</select>';

					// Background Position
					$output .= '<select class="freshthemes-background freshthemes-background-position" name="' . esc_attr( $option_name . '[' . $value['id'] . '][position]' ) . '" id="' . esc_attr( $value['id'] . '_position' ) . '">';
					$positions = freshthemes_recognized_background_position();

					foreach ($positions as $key=>$position) {
						$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $background['position'], $key, false ) . '>'. esc_html( $position ) . '</option>';
					}
					$output .= '</select>';

					// Background Attachment
					$output .= '<select class="freshthemes-background freshthemes-background-attachment" name="' . esc_attr( $option_name . '[' . $value['id'] . '][attachment]' ) . '" id="' . esc_attr( $value['id'] . '_attachment' ) . '">';
					$attachments = freshthemes_recognized_background_attachment();

					foreach ($attachments as $key => $attachment) {
						$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $background['attachment'], $key, false ) . '>' . esc_html( $attachment ) . '</option>';
					}
					$output .= '</select>';
					$output .= '</div>';
					break;
					
				/* Editor */
				case 'editor':
					$output .= '<div class="explain">' . wp_kses( $explain_value, $allowedtags) . '</div><div class="clear"></div>'."\n";
					echo $output;
					$textarea_name = esc_attr( $option_name . '[' . $value['id'] . ']' );
					$default_editor_settings = array(
						'textarea_name' => $textarea_name,
						'media_buttons' => false,
						'tinymce' => array( 'plugins' => 'wordpress' )
					);
					$editor_settings = array();
					if ( isset( $value['settings'] ) ) {
						$editor_settings = $value['settings'];
					}
					$editor_settings = array_merge($editor_settings, $default_editor_settings);
					wp_editor( $val, $value['id'], $editor_settings );
					$output = '';
					break;
					
				/* Heading for Navigation */
				case 'heading':
					if ($counter >= 2) {
						$output .= '</div>';
					}
					$jquery_click_hook = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['std']) );
					$jquery_click_hook = "freshthemes-option-" . $jquery_click_hook;
					
					$output .= '<div class="group" id="' . esc_attr( $jquery_click_hook ) . '">';
					$output .= '<h3>' . esc_html( $value['name'] ) . '</h3>';
					break;
					
				case 'subheading':
					if ($counter >= 2) {
						$output .= '</div>';
					}
					$jquery_click_hook = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['std']) );
					$jquery_click_hook = "freshthemes-option-" . $jquery_click_hook;
					
					$output .= '<div class="group" id="' . esc_attr( $jquery_click_hook ) . '">';
					$output .= '<h3>' . esc_html( $value['name'] ) . '</h3>';
					break;
					
				/* Info */
				case "info":
					$id = '';
					$class = 'section';
					
					if ( isset( $value['id'] ) ) {
						$id = 'id="' . esc_attr( $value['id'] ) . '" ';
					}
					if ( isset( $value['type'] ) ) {
						$class .= ' section-' . $value['type'];
					}
					if ( isset( $value['class'] ) ) {
						$class .= ' ' . $value['class'];
					}

					$output .= '<div ' . $id . 'class="' . esc_attr( $class ) . '">' . "\n";
					if ( isset($value['name']) ) {
						$output .= '<h4 class="heading">' . esc_html( $value['name'] ) . '</h4>' . "\n";
					}
					if ( $value['desc'] ) {
						$output .= apply_filters('freshthemes_sanitize_info', $value['desc'] ) . "\n";
					}
					$output .= '</div>' . "\n";
					break;
					
			}
			
			if ( ( $value['type'] != "heading" ) && ( $value['type'] != "subheading" ) && ( $value['type'] != "info" ) ) {
				$output .= '</div>' . "\n";
				if ( ( $value['type'] != "checkbox" ) && ( $value['type'] != "editor" ) ) {
					$output .= '<div class="explain">' . wp_kses( $explain_value, $allowedtags) . '</div>' . "\n";
				}
				$output .= '</div><div class="clear"></div></div>' . "\n";
			}
			
			echo $output;
		}
		
		echo '</div><!-- group -->';
	}
