/**
 *	FreshTheme Metabox Script
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki A.G
 *	@version	: 1.2
 *	@copyright	: Copyright (c) 2012, FreshThemes
 *				  http://www.freshthemes.net
 *				  http://www.rifki.net
 *	--------------------------------------------------------------------------- */
 
(function ($) {	

	var FreshMetabox = {
		
		// Init color picker.
		initColorPicker: function() {
			$('.fresh-metabox .fresh_colorpicker').each(function(e) {
				$(this).after('<div id="picker-'+ e +'" class="fresh-picker">');
				$('#picker-' + e).hide().farbtastic($(this));
            })
			.focus(function() {
				$(this).next().show();
			})
			.blur(function() {
				$(this).next().hide();
			});
		},
		
		// Init date picker.
		initDatePicker: function() {
			$('.fresh-metabox .fresh-date-picker').each(function(e) {
				format = $(this).attr('rel');
				$(this).removeClass('hasDatepicker').attr('id', '').datepicker( {
					showButtonPanel: true,
					dateFormat: format
				});
            });
		},
		
		// Radio image selector.
		imageSelector: function() {
			$('.fresh-image-selector-img').click(function(){
				$(this).parent().parent().find('.fresh-image-selector-img').removeClass('fresh-image-selector-img-selected');
				$(this).addClass('fresh-image-selector-img-selected');		
			});
				
			$('.fresh-image-selector-label').hide();
			$('.fresh-image-selector-img').show();
			$('.fresh-image-selector').hide();
		},
		
		// Initialize sortable.
		initRatingCriteria: function() {
			$('.sorttrue').sortable();
		},
		
		// Delete rating criteria.
		removeCriteria: function() {
			$('.sorttrue a.delete').live('click', function() {
				if( $('.sorttrue li').size() == 1) {
					alert('sorry you need at least one criteria');
				} else {
					if(window.confirm("Are You Sure?")) $(this).parents('li').remove();
				}
			});
		},
		
		addNewCriteria: function() {
			e = 0;
			i = '';
			
			if (typeof(CRITERIA_COUNT) != 'undefined' ) {
				e = CRITERIA_COUNT;
			}
			
			if (typeof(CRITERIA_ID) != 'undefined' ) {
				i = CRITERIA_ID;
			}
			
			$('.add-criteria').click(function() {
				e = e + 1;
				$('.sorttrue').append('<li><span class="icon"></span><span class="criteria-name"><label for="'+ i +'['+e+'][c_label]">برچسب:</label><input type="text" name="'+ i +'['+e+'][c_label]]" value="" /></span><span class="criteria-score"><label for="'+ i +'['+e+'][score]">امتیاز:</label><input type="text" name="'+ i +'['+e+'][score]" value="" /></span><span class="criteria-button"><a class="delete" title="Delete">X</a></span></li>');
				return false;
			});
		},
		
		// Hide / unhide review box.
		hideUnhideClick: function() {
			var trigger = $('.fresh-trigger');
			trigger.parents('tr').nextAll().hide();
			
			if(trigger.is(':checked'))
			trigger.addClass('active').parents('tr').nextAll().show();
		
			trigger.live('click', function (e) {
				if( trigger.hasClass('active') ) {
					$(this).removeClass('active').parents('tr').nextAll().hide();
				}
				else {
					$(this).addClass('active').parents('tr').nextAll().show();
				}
			});
		},
		
		// Initialize.
		init: function() {
			FreshMetabox.initColorPicker();
			FreshMetabox.initDatePicker();
			FreshMetabox.imageSelector();
			FreshMetabox.initRatingCriteria();
			FreshMetabox.addNewCriteria();
			FreshMetabox.removeCriteria();
			FreshMetabox.hideUnhideClick();
		}
		
	}
	
	// Run the magic.
	$(document).ready(function(e) {
		FreshMetabox.init();
		
		// Hide all post format metaboxes.
		var std_box = $('#std_post_format_options'); var std_trigger = $('#post-format-0'); std_box.hide();
		var image_box = $('#image_post_format_options'); var image_trigger = $('#post-format-image'); image_box.hide();
		var gallery_box = $('#gallery_post_format_options'); var gallery_trigger = $('#post-format-gallery'); gallery_box.hide();
		var video_box = $('#video_post_format_options'); var video_trigger = $('#post-format-video'); video_box.hide();
		
		// Define triggers group.
		var group = $('#post-formats-select input');
		
		// When the post format changed.
		group.change( function() {
			if($(this).val() == 0) {
				std_box.show();
				hide_all(std_box);
			} 
			else if($(this).val() == 'image') {
				image_box.show();
				hide_all(image_box);
			} 
			else if($(this).val() == 'gallery') {
				gallery_box.show();
				hide_all(gallery_box);
			} 
			else if($(this).val() == 'video') {
				video_box.show();
				hide_all(video_box);
			} 
			else {
				std_box.show();
				image_box.show();
				gallery_box.show();
				video_box.show();
			}
		});
		
		// If the trigger is checked let show the metabox.
		if(std_trigger.is(':checked')) std_box.show();
		if(image_trigger.is(':checked')) image_box.show();
		if(gallery_trigger.is(':checked')) gallery_box.show();
		if(video_trigger.is(':checked')) video_box.show();
			
		// Hide all metaboxes but show only active trigger.
		function hide_all(notThisOne) {
			std_box.hide();
			image_box.hide();
			gallery_box.hide();
			video_box.hide();
			notThisOne.show();
		}
		
		// Hide Background Properties
		var default_properties = $('#hotnewsbackground_color_box, #hotnewsbackground_repeat_box, #hotnewsbackground_position_box, #hotnewsbackground_attachment_box');
		var default_trigger = $('#hotnewscustom_background_box #hotnewscustom_background_normal');
		default_properties.hide();
		
		var backstrech_properties = $('#hotnewsbackground_image_box');
		var backstrech_trigger = $('#hotnewscustom_background_box #hotnewscustom_background_backstrech');
		backstrech_properties.hide();
		
		// When the trigger changed.
		$('#hotnewscustom_background_box input').change( function() {
			if($(this).val() == 'normal') {
				default_properties.slideDown();
				backstrech_properties.slideDown();
			} else if($(this).val() == 'backstrech') {
				default_properties.hide();
				backstrech_properties.slideDown();
			} else {
				default_properties.hide();
				backstrech_properties.hide();
			}
		});
		
		// Shows active metaboxes.
		if(default_trigger.is(':checked')) {
			default_properties.slideDown();
			backstrech_properties.slideDown();
		}
		if(backstrech_trigger.is(':checked')) {
			default_properties.hide();
			backstrech_properties.slideDown();
		}
    });

})(jQuery);