﻿<?php
/**
 *	FreshTheme Metabox
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki A.G
 *	@version	: 1.2
 *	@copyright	: Copyright (c) 2012, FreshThemes
 *				  http://www.freshthemes.net
 *				  http://www.20script.ir
 *	--------------------------------------------------------------------------- */
 
class FreshMetabox {
	
	protected $_metabox;
	
/*	Contruct
 *	--------------------------------------------------------- */
	function __construct($metabox) {
		if ( !is_admin() ) 
		return;
		
		$this->_metabox = $metabox;
		
		add_action('admin_menu', array(&$this, 'register_fresh_metabox'));
		add_action('save_post', array(&$this, 'save_fresh_metabox'));
	}
	
/*	Register
 *	--------------------------------------------------------- */
	function register_fresh_metabox() {
		$this->_metabox['context'] = empty($this->_metabox['context']) ? 'normal' : $this->_metabox['context'];
		$this->_metabox['priority'] = empty($this->_metabox['priority']) ? 'high' : $this->_metabox['priority'];
		
		foreach ( $this->_metabox['pages'] as $page ) {
			add_meta_box(
				$this->_metabox['id'], 
				$this->_metabox['title'], 
				array(&$this, 'show_fresh_metabox'), 
				$page, 
				$this->_metabox['context'], 
				$this->_metabox['priority']
			);
		}
	}

/*	Show
 *	--------------------------------------------------------- */	
	function show_fresh_metabox() {
		global $post;
		
		echo '<input type="hidden" name="wp_meta_box_nonce" value="', wp_create_nonce( basename(__FILE__) ), '" />';
		echo '<table class="form-table fresh-metabox">';
		foreach ( $this->_metabox['fields'] as $field ) {
			if (!isset($field['name'])) $field['name'] = '';
			if (!isset($field['desc'])) $field['desc'] = '';
			if (!isset($field['std'])) $field['std'] = '';
			if (!isset($field['class'])) $field['class'] = '';
			
			// get value of this field if it exists for this post
			$meta = get_post_meta($post->ID, $field['id'], true);
			
			// Use standard value if empty
			$meta = ('' === $meta || array() === $meta) ? $field['std'] : $meta;
			
			echo '<tr id="'.$field['id'].'_box"><th><label for="'.$field['id'].'">'.$field['name'].'</label></th><td>';
			switch($field['type']) {
				
				// text
				case 'text':
					echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" />';
					echo '<br /><span class="description">'.$field['desc'].'</span>';
					break;
					
				// textarea
				case 'textarea':
					$rows = '8';

					if ( isset( $field['settings']['rows'] ) ) {
						$custom_rows = $field['settings']['rows'];
						if ( is_numeric( $custom_rows ) ) {
							$rows = $custom_rows;
						}
					}
					$meta = stripslashes( $meta );
					
					echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="'.$rows.'">'.esc_textarea($meta).'</textarea>';
					echo '<br /><span class="description">'.$field['desc'].'</span>';
					break;
				
				// checkbox
				case 'checkbox':
					echo '<label><input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" class="fresh-'.$field['class'].'" ',$meta ? ' checked="checked"' : '','/><span>'.$field['desc'].'</span></label>';
					break;
				
				// select
				case 'select':
					echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
					foreach ($field['options'] as $key => $val) {
						echo '<option', $meta == $key ? ' selected="selected"' : '', ' value="'.$key.'">'.$val.'</option>';
					}
					echo '</select><br /><span class="description">'.$field['desc'].'</span>';
					break;
				
				// radio
				case 'radio':
					foreach ( $field['options'] as $key => $val ) {
						echo '<label><input type="radio" name="'.$field['id'].'" id="'.$field['id'].'_'.$key.'" value="'.$key.'" ',$meta == $key ? ' checked="checked"' : '',' /><span>'.$val.'</span></label>';
					}
					break; 
				
				// images selector
				case 'images':
					foreach ( $field['options'] as $key => $val ) {
						echo '<input class="fresh-image-selector" type="radio" name="'.$field['id'].'" id="'.$field['id'].'_'.$key.'" value="'.$key.'" ',$meta == $key ? ' checked="checked"' : '',' />';
						echo '<div class="fresh-image-selector-label">'.esc_html( $key ).' ',$meta == $key ? ' This is selected' : 'This is unselected','</div>';
						echo '<img src="'.esc_url( $val ).'" alt="'.$key.'" class="fresh-image-selector-img ',$meta == $key ? ' fresh-image-selector-img-selected' : '','" onclick="document.getElementById(\''. esc_attr($field['id'] .'_'. $key) .'\').checked=true;" />';
					}
					break; 
				
				// color
				case 'color':
					$hex_color = '(([a-fA-F0-9]){3}){1,2}$';
					if ( preg_match( '/^' . $hex_color . '/i', $meta ) ) // Value is just 123abc, so prepend #.
						$meta = '#' . $meta;
					elseif ( ! preg_match( '/^#' . $hex_color . '/i', $meta ) ) // Value doesn't match #123abc, so sanitize to just #.
						$meta = "#";
					echo '<input class="fresh_colorpicker" type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $meta, '" />
					<span class="description">', $field['desc'], '</span>';
					break;
					
				// text
				case 'date':
					echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" class="fresh-date-picker" rel="'.$field['format'].'" value="'.$meta.'" size="30" />';
					echo '<br /><span class="description">'.$field['desc'].'</span>';
					break;
					
				// upload
				case 'upload':
					if ($meta) { 
						$image = wp_get_attachment_image_src($meta, 'medium');	$image = $image[0]; 
					}
					else {
						$image = '';
					}
					
					
					echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" class="upload" value="'.$meta.'" size="30" />';
					echo '<input type="button" id="upload-'.$field['id'].'" class="upload_button button" value="'.__( 'بارگذاری', THEME_FX ).'" rel="'.$post->ID.'" />';
					echo '<div class="screenshot'.( $meta != '' ? '' : ' empty' ).'" id="'.$field['id'].'_image">';
					if ( $meta != '' ) { 
						$remove = '<a href="#" class="mlu_remove" title="Delete this image">X</a>';
						$image = preg_match( '/(^.*\.jpg|jpeg|png|gif|ico*)/i', $meta );
						
						if ( $image ) {
							echo '<img src="'.$meta.'" alt="" />'.$remove;
						} 
						else {
							echo '';
						}	
					}
					echo '</div>';
					break;
					
				// repeated
				case 'rating_criteria':
					$rows = array();
					if($meta) $rows = $meta;
					$c = 0;
					
					echo '<ul id="'.$field['id'].'-citeria-placeholder" class="sorttrue">';
					if ( count( $rows ) > 0 ) {
						foreach( $rows as $row ) {
							if ( isset( $row['c_label'] ) || isset( $row['score'] ) ) {
								echo '<li><span class="icon"></span><span class="criteria-name"><label for="'.$field['id'].'['.$c.'][c_label]">برچسب:</label><input type="text" name="'.$field['id'].'['.$c.'][c_label]" value="'.$row['c_label'].'" /></span><span class="criteria-score"><label for="'.$field['id'].'['.$c.'][score]">امتیاز:</label><input type="text" name="'.$field['id'].'['.$c.'][score]" value="'.$row['score'].'" /></span><span class="criteria-button"><a class="delete" title="Delete">X</a></span></li>';
								$c = $c + 1;
							}
						}
					} 
					else {
						echo '<li><span class="icon"></span><span class="criteria-name"><label for="'.$field['id'].'[0][c_label]">برچسب:</label><input type="text" name="'.$field['id'].'[0][c_label]" value="'.$row['c_label'].'" /></span><span class="criteria-score"><label for="'.$field['id'].'[0][score]">امتیاز:</label><input type="text" name="'.$field['id'].'[0][score]" value="'.$row['score'].'" /></span><span class="criteria-button"><a class="delete" title="Delete">X</a></span></li>';
					}
					echo '</ul>';
					//echo '<ul class="sorttrue" id="criteria-placeholder"></ul>';
					echo '<a class="add-criteria button-primary" href="#">Add Criteria</a>';
					echo '<br /><span class="description">'.$field['desc'].'</span>';
					echo '<script>
							var CRITERIA_COUNT = "'.$c.'";
							var CRITERIA_ID = "'.$field['id'].'";
						</script>';
					break;
					
			} //endswitch
			echo '</td></tr>';
		}
		echo '</table>';
	}

/*	Save
 *	--------------------------------------------------------- */	
	function save_fresh_metabox($post_id) {
		
		// verify nonce
		if ( !isset($_POST['wp_meta_box_nonce']) || !wp_verify_nonce($_POST['wp_meta_box_nonce'], basename(__FILE__)) ) {
			return $post_id;
		}
		
		// check autosave
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return $post_id;
		}
		
		// check permission
		if ('page' == $_POST['post_type']) {
			if ( !current_user_can('edit_page', $post_id) ) {
				return $post_id;
			}
			elseif ( !current_user_can('edit_post', $post_id )) {
				return $post_id;
			}
		}
		
		// save data
		foreach ( $this->_metabox['fields'] as $field ) {
			$old = get_post_meta($post_id, $field['id'], true);
			$new = isset( $_POST[$field['id']] ) ? $_POST[$field['id']] : null;
			
			if ($new && $new != $old) {
				update_post_meta($post_id, $field['id'], $new);
			} 
			elseif ('' == $new && $old) {
				delete_post_meta($post_id, $field['id'], $old);
			}
		}
	}
	
} // end class.

/*	Load Scripts and Styles
 *	--------------------------------------------------------- */
	function fresh_metabox_scripts_and_styles($hook) {
		global $wp_scripts;
		$ui = $wp_scripts->query('jquery-ui-core');
		
		if ( $hook == 'post.php' || $hook == 'post-new.php' || $hook == 'page-new.php' || $hook == 'page.php' ) {
			wp_enqueue_script('jquery-ui-slider');
			wp_enqueue_script('jquery-ui-sortable');
			wp_enqueue_script('jquery-ui-datepicker'); 
			wp_enqueue_script('farbtastic'); 
			wp_enqueue_script('fresh-metabox-mlu', THEME_DIR . '/functions/framework/javascripts/media-uploader.js');
			wp_enqueue_script('fresh-metabox-script', THEME_DIR . '/functions/framework/javascripts/metabox.js');
			
			wp_enqueue_style('farbtastic'); 
			wp_enqueue_style('jquery-ui-datepicker-css',"http://code.jquery.com/ui/{$ui->ver}/themes/base/jquery-ui.css", false, $ui->ver);
			wp_enqueue_style('fresh-metabox-style', THEME_DIR . '/functions/framework/stylesheets/metabox.css', array('thickbox'));
		}
	}
	
	add_action( 'admin_enqueue_scripts', 'fresh_metabox_scripts_and_styles', 10 );
	
/*	Initialize Metabox
 *	--------------------------------------------------------- */
	function fresh_init_metaboxes() {
		if ( class_exists( 'FreshMetabox' ) ) {
			require_once THEME_PATH . '/functions/theme-metaboxes.php';
			
			$metaboxes = array();
			$metaboxes = apply_filters ('fresh_metaboxes' , $metaboxes);
			foreach ( $metaboxes as $metabox ) {
				$my_box = new FreshMetabox($metabox);
			}
		}
	}
	
	add_action( 'init', 'fresh_init_metaboxes', 9999 );