<?php
/**
 *	FreshTheme Framework Admin Sanitize
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki A.G
 *	@version	: 1.2
 *	@copyright	: Copyright (c) 2012, FreshThemes
 *				  http://www.freshthemes.net
 *				  http://www.rifki.net
 *	@credits	: Devin Price, http://wptheming.com/
 *	              WooThemes, http://www.woothemes.com/
 *				  Gilles Vauvarin
 *	--------------------------------------------------------------------------- */

/*	Text
 *	------------------------------------------------------------------- */
	add_filter( 'freshthemes_sanitize_text', 'sanitize_text_field' );
	
/* 	Textarea
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_textarea($input) {
		$output = $input;
		return $output;
	}
	
	add_filter( 'freshthemes_sanitize_textarea', 'freshthemes_sanitize_textarea' );

/* 	Select 
 *	------------------------------------------------------------------- */
	add_filter( 'freshthemes_sanitize_select', 'freshthemes_sanitize_enum', 10, 2);

/* 	Radio 
 *	------------------------------------------------------------------- */
	add_filter( 'freshthemes_sanitize_radio', 'freshthemes_sanitize_enum', 10, 2);

/* 	Images 
 *	------------------------------------------------------------------- */
	add_filter( 'freshthemes_sanitize_images', 'freshthemes_sanitize_enum', 10, 2);

/* 	Checkbox 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_checkbox( $input ) {
		if ( $input ) {
			$output = '1';
		} else {
			$output = false;
		}
		return $output;
	}
	
	add_filter( 'freshthemes_sanitize_checkbox', 'freshthemes_sanitize_checkbox' );

/*	Multicheck 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_multicheck( $input, $option ) {
		$output = '';
		if ( is_array( $input ) ) {
			foreach( $option['options'] as $key => $value ) {
				$output[$key] = "0";
			}
			foreach( $input as $key => $value ) {
				if ( array_key_exists( $key, $option['options'] ) && $value ) {
					$output[$key] = "1";
				}
			}
		}
		return $output;
	}
	add_filter( 'freshthemes_sanitize_multicheck', 'freshthemes_sanitize_multicheck', 10, 2 );

/*	Color Picker 
 *	------------------------------------------------------------------- */
	add_filter( 'freshthemes_sanitize_color', 'freshthemes_sanitize_hex' );
	
/* 	Uploader 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_upload( $input ) {
		$output = '';
		$filetype = wp_check_filetype($input);
		if ( $filetype["ext"] ) {
			$output = $input;
		}
		return $output;
	}
	
	add_filter( 'freshthemes_sanitize_upload', 'freshthemes_sanitize_upload' );
	
/* 	Color sanitize hexidecimal notation 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_hex( $hex, $default = '' ) {
		if ( freshthemes_validate_hex( $hex ) ) {
			return $hex;
		}
		return $default;
	}
	
/* 	Color validate hexidecimal notation 
 *	------------------------------------------------------------------- */
	function freshthemes_validate_hex( $hex ) {
		$hex = trim( $hex );
		/* Strip recognized prefixes. */
		if ( 0 === strpos( $hex, '#' ) ) {
			$hex = substr( $hex, 1 );
		}
		elseif ( 0 === strpos( $hex, '%23' ) ) {
			$hex = substr( $hex, 3 );
		}
		/* Regex match. */
		if ( 0 === preg_match( '/^[0-9a-fA-F]{6}$/', $hex ) ) {
			return false;
		}
		else {
			return true;
		}
	}

	add_filter( 'freshthemes_sanitize_color', 'freshthemes_sanitize_hex' );
	
/* 	Allowed Tags 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_allowedtags($input) {
		global $allowedtags;
		$output = wpautop(wp_kses( $input, $allowedtags));
		return $output;
	}

/* 	Allowed Post Tags 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_allowedposttags($input) {
		global $allowedposttags;
		$output = wpautop(wp_kses( $input, $allowedposttags));
		return $output;
	}

	add_filter( 'freshthemes_sanitize_info', 'freshthemes_sanitize_allowedposttags' );

/*	Check that the key value sent is valid 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_enum( $input, $option ) {
		$output = '';
		if ( array_key_exists( $input, $option['options'] ) ) {
			$output = $input;
		}
		return $output;
	}

/*	Typography 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_typography( $input, $option ) {
		$output = wp_parse_args( $input, array(
			'size'  => '',
			'face'  => '',
			'style' => '',
			'color' => ''
		));

		if ( isset( $option['options']['faces'] ) && isset( $input['face'] ) ) {
			if ( !( array_key_exists( $input['face'], $option['options']['faces'] ) ) ) {
				$output['face'] = '';
			}
		} else {
			$output['face']  = apply_filters( 'freshthemes_font_face', $output['face'] );
		}

		$output['size']  = apply_filters( 'freshthemes_font_size', $output['size'] );
		$output['style'] = apply_filters( 'freshthemes_font_style', $output['style'] );
		$output['color'] = apply_filters( 'freshthemes_color', $output['color'] );
		
		return $output;
	}
	
	add_filter( 'freshthemes_sanitize_typography', 'freshthemes_sanitize_typography', 10, 2 );

	function freshthemes_sanitize_font_size( $value ) {
		$recognized = freshthemes_recognized_font_sizes();
		$value_check = preg_replace('/px/','', $value);
		if ( in_array( (int) $value_check, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'freshthemes_default_font_size', $recognized );
	}
	
	add_filter( 'freshthemes_font_size', 'freshthemes_sanitize_font_size' );


	function freshthemes_sanitize_font_style( $value ) {
		$recognized = freshthemes_recognized_font_styles();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'freshthemes_default_font_style', current( $recognized ) );
	}

	add_filter( 'freshthemes_font_style', 'freshthemes_sanitize_font_style' );


	function freshthemes_sanitize_font_face( $value ) {
		$recognized = freshthemes_recognized_font_faces();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'freshthemes_default_font_face', current( $recognized ) );
	}

	add_filter( 'freshthemes_font_face', 'freshthemes_sanitize_font_face' );

/* 	Get recognized font sizes.
 *	------------------------------------------------------------------- */
	function freshthemes_recognized_font_sizes() {
		$sizes = range( 9, 71 );
		$sizes = apply_filters( 'freshthemes_recognized_font_sizes', $sizes );
		$sizes = array_map( 'absint', $sizes );
		return $sizes;
	}

/* 	Get recognized font faces
 *	------------------------------------------------------------------- */
	function freshthemes_recognized_font_faces() {
		$default = array(
			'arial'     => 'Arial',
			'verdana'   => 'Verdana, Geneva',
			'trebuchet' => 'Trebuchet',
			'georgia'   => 'Georgia',
			'times'     => 'Times New Roman',
			'tahoma'    => 'Tahoma, Geneva',
			'palatino'  => 'Palatino',
			'helvetica' => 'Helvetica*'
		);
		return apply_filters( 'freshthemes_recognized_font_faces', $default );
	}

/*	Get recognized font styles.
 *	------------------------------------------------------------------- */
	function freshthemes_recognized_font_styles() {
		$default = array(
			'normal'      => __('Normal', THEME_FX),
			'italic'      => __('Italic', THEME_FX),
			'bold'        => __('Bold', THEME_FX),
			'bold italic' => __('Bold Italic', THEME_FX)
		);
		return apply_filters( 'freshthemes_recognized_font_styles', $default );
	}
	

/* 	Background 
 *	------------------------------------------------------------------- */
	function freshthemes_sanitize_background( $input ) {
		$output = wp_parse_args( $input, array(
			'color' => '',
			'image'  => '',
			'repeat'  => 'repeat',
			'position' => 'top center',
			'attachment' => 'scroll'
		));

		$output['color'] = apply_filters( 'freshthemes_sanitize_hex', $input['color'] );
		$output['image'] = apply_filters( 'freshthemes_sanitize_upload', $input['image'] );
		$output['repeat'] = apply_filters( 'freshthemes_background_repeat', $input['repeat'] );
		$output['position'] = apply_filters( 'freshthemes_background_position', $input['position'] );
		$output['attachment'] = apply_filters( 'freshthemes_background_attachment', $input['attachment'] );

		return $output;
	}

	add_filter( 'freshthemes_sanitize_background', 'freshthemes_sanitize_background' );

	function freshthemes_sanitize_background_repeat( $value ) {
		$recognized = freshthemes_recognized_background_repeat();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'freshthemes_default_background_repeat', current( $recognized ) );
	}
	
	add_filter( 'freshthemes_background_repeat', 'freshthemes_sanitize_background_repeat' );

	function freshthemes_sanitize_background_position( $value ) {
		$recognized = freshthemes_recognized_background_position();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'freshthemes_default_background_position', current( $recognized ) );
	}
	
	add_filter( 'freshthemes_background_position', 'freshthemes_sanitize_background_position' );

	function freshthemes_sanitize_background_attachment( $value ) {
		$recognized = freshthemes_recognized_background_attachment();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'freshthemes_default_background_attachment', current( $recognized ) );
	}

	add_filter( 'freshthemes_background_attachment', 'freshthemes_sanitize_background_attachment' );

/*	Get recognized background repeat settings
 *	------------------------------------------------------------------- */
	function freshthemes_recognized_background_repeat() {
		$default = array(
			'no-repeat' => __('بدون تکرار', THEME_FX),
			'repeat-x'  => __('تکرار افقی', THEME_FX),
			'repeat-y'  => __('تکرار عمودی', THEME_FX),
			'repeat'    => __('تکرار همه', THEME_FX),
		);
		return apply_filters( 'freshthemes_recognized_background_repeat', $default );
	}

/* 	Get recognized background positions
 *	------------------------------------------------------------------- */
	function freshthemes_recognized_background_position() {
		$default = array(
			'top left'      => __('بالا چپt', THEME_FX),
			'top center'    => __('بالا وسط', THEME_FX),
			'top right'     => __('بالا راست', THEME_FX),
			'center left'   => __('وسط چپ', THEME_FX),
			'center center' => __('وسط وسط', THEME_FX),
			'center right'  => __('وسط راست', THEME_FX),
			'bottom left'   => __('پایین چپ', THEME_FX),
			'bottom center' => __('پایین وسط', THEME_FX),
			'bottom right'  => __('پایین راست', THEME_FX)
		);
		return apply_filters( 'freshthemes_recognized_background_position', $default );
	}

/* 	Get recognized background attachment
 *	------------------------------------------------------------------- */
	function freshthemes_recognized_background_attachment() {
		$default = array(
			'scroll' => __('معمولی', THEME_FX),
			'fixed'  => __('ثابت در یک مکان', THEME_FX)
			);
		return apply_filters( 'freshthemes_recognized_background_attachment', $default );
	}