<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package	   TGM-Plugin-Activation
 * @subpackage Example
 * @version	   2.3.6
 * @author	   Thomas Griffin <thomas@thomasgriffinmedia.com>
 * @author	   Gary Jones <gamajo@gamajo.com>
 * @copyright  Copyright (c) 2012, Thomas Griffin
 * @license	   http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once dirname( __FILE__ ) . '/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'my_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function my_theme_register_required_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// This is an example of how to include a plugin pre-packaged with a theme
		array(
			'name'     				=> 'Fresh Shortcodes', // The plugin name
			'slug'     				=> 'fresh-shortcodes', // The plugin slug (typically the folder name)
			'source'   				=> get_stylesheet_directory() . '/functions/plugins/fresh-shortcodes.zip', // The plugin source
			'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
			'version' 				=> '1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
			'force_activation' 		=> true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
		),

		// This is an example of how to include a plugin from the WordPress Plugin Repository
		array(
			'name' 		=> 'WP-PostViews',
			'slug' 		=> 'wp-postviews',
			'required' 	=> true,
		),
		array(
			'name' 		=> 'WP-PageNavi',
			'slug' 		=> 'wp-pagenavi',
			'required' 	=> true,
		),

	);
	
	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'       		=> THEME_FX,         	// Text domain - likely want to be the same as your theme.
		'default_path' 		=> '',                         	// Default absolute path to pre-packaged plugins
		'parent_menu_slug' 	=> 'fresh-panel',		// Default parent menu slug
		'parent_url_slug' 	=> 'admin.php', 				// Default parent URL slug
		'menu'         		=> 'install-required-plugins', 	// Menu slug
		'has_notices'      	=> true,                       	// Show admin notices or not
		'is_automatic'    	=> false,					   	// Automatically activate plugins after installation or not
		'message' 			=> '',							// Message to output right before the plugins table
		'strings'      		=> array(
			'page_title'                       			=> __( 'نصب افزونه‌های مورد نیاز', THEME_FX ),
			'menu_title'                       			=> __( 'نصب افزونه‌ها', THEME_FX ),
			'installing'                       			=> __( 'نصب افزونه: %s', THEME_FX ), // %1$s = plugin name
			'oops'                             			=> __( 'در API افزونه مشکلی ایجاد شده است.', THEME_FX ),
			'notice_can_install_required'     			=> _n_noop( 'این پوسته شامل بسته‌ای از افزونه‌ روبرو است: %1$s.', 'این پوسته شامل بسته‌ای از افزونه‌های روبرو است: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'			=> _n_noop( 'این پوسته شامل بسته‌ای از افزونه‌ روبرو است: %1$s.', 'این پوسته شامل بسته‌ای از افزونه‌های روبرو است: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_install'  					=> _n_noop( 'متاسفیم، ولی شما اجازه نصب افزونه %s را ندارید. برای نصب یا گرفتن کمک با مدیر سایت تماس بگیرید.', 'متاسفیم، ولی شما اجازه نصب افزونه‌های %s را ندارید. برای نصب یا گرفتن کمک با مدیر سایت تماس بگیرید.' ), // %1$s = plugin name(s)
			'notice_can_activate_required'    			=> _n_noop( 'افزونه لازم روبرو در حال حاضر غیرفعال است: %1$s.', 'افزونه‌های لازم روبرو در حال حاضر غیرفعال است: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended'			=> _n_noop( 'افزونه پیشنهادی روبرو در حال حاضر غیرفعال است: %1$s.', 'افزونه‌های پیشنهادی روبرو در حال حاضر غیرفعال است: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_activate' 					=> _n_noop( 'متاسفیم، ولی شما اجازه فعال کردن افزونه %s را ندارید. برای فعال کردن یا گرفتن کمک با مدیر سایت تماس بگیرید.', 'متاسفیم، ولی شما اجازه فعال کردن افزونه‌های %s را ندارید. برای فعال کردن یا گرفتن کمک با مدیر سایت تماس بگیرید.' ), // %1$s = plugin name(s)
			'notice_ask_to_update' 						=> _n_noop( 'افزونه روبروی برای اطمینان از سازگاری با پوسته باید به آخرین نسخه خود به‌روزرسانی شود: %1$s.', 'افزونه‌های روبروی برای اطمینان از سازگاری با پوسته باید به آخرین نسخه خود به‌روزرسانی شود: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_update' 						=> _n_noop( 'متاسفیم، ولی شما اجازه به‌روزرسانی کردن افزونه %s را ندارید. برای به‌روزرسانی کردن یا گرفتن کمک با مدیر سایت تماس بگیرید.', 'متاسفیم، ولی شما اجازه به‌روزرسانی کردن افزونه‌های %s را ندارید. برای به‌روزرسانی کردن یا گرفتن کمک با مدیر سایت تماس بگیرید.' ), // %1$s = plugin name(s)
			'install_link' 					  			=> _n_noop( 'شروع نصب افزونه', 'Begin installing plugins' ),
			'activate_link' 				  			=> _n_noop( 'فعال کردن افزونه نصب شده', 'Activate installed plugins' ),
			'return'                           			=> __( 'بازگشت به نصب‌کننده افزونه‌ها', THEME_FX ),
			'plugin_activated'                 			=> __( 'افزونه با موفقیت فعال شد.', THEME_FX ),
			'complete' 									=> __( 'همه افزونه‌ها با موفقیت نصب و فعال‌سازی شدند. %s', THEME_FX ), // %1$s = dashboard link
			'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );

}